<div class="navbar">
    <div class="navbar-brand">
         <img src="/static/favicon.png" width="50" height="14">
        <a href="/fe/" class="navbar-item">Fact Explorer</a>
    </div>
    <div class="navbar-menu">
        <a href="/fe/" class="navbar-item">Last Minutes</a>
        <a href="/fe/search" class="navbar-item">Search</a>
        <a href="/docs/" class="navbar-item" target="_blank">API Docs</a>
    </div>
</div>
